%
%  This script generates example problem 
%
%
%  First, the v,D transport parameters.
%
params=[1.0, 1.0];   % [v,D]
%
%  Locations and times of samples.
%
xsample=5:5:300;
tsample=300;
nt=100;
tmax=300.;
tmin=0.;
%
% And the time points at which we'll estimate the source concentration
%
if (tmax == tsample)
	t=linspace(tmin,tsample,nt+1);
	t=t(1:nt);
else
	t=linspace(tmin,tmax,nt);
end
%
% Make t a column vector.
%
t=t';
%
%  Compute the G matrix.
%
g=getrep('kernel',t',xsample,tsample,params);
%
%  Compute the correct data.  
%
cin=feval('cintrue',t);
cout=g*cin;

% set the random number generator to its initial state so the
% problem is repeatable;
randn('state',0);

% compute data with measurement error (d vector)
d=cout+0.005*randn(size(cout));

%
%  Now, setup the prior expected value, lower bounds, and upper bounds, etc.
%
upper=1.1*ones(nt,1);
lower=zeros(nt,1);
%
% Gaussian expected value function.
%
expvalue=zeros(nt,1);
expvalue=exp(-((t-150).^2)/(2*20^2));
%
%  Noise level in the form noise = [epsilon_a epsilon_m].  
%
noise=[0.005 0.0];
%
%  Finally, have the MRE routine solve the problem.
%
[x,lambda,beta,a,p5,p95]=mre(g,d,upper,lower,expvalue,noise)

